/***************************************************************************
 *   Copyright (C) 2006 by George Kiagiadakis   *
 *   gkiagia@users.sourceforge.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "version.h"
#include "reginstaller.h"
#include <QtGui>
#include <QMessageBox>
#include <QString>
#include <QStringList>
#include <QFileInfo>
#include <QTextStream>
#include "winelauncher.h"
#include "macros.h"
#include "configdelegate.h"

regInstaller::regInstaller(QWidget *parent)
 : QDialog(parent)
{
	rif.setupUi(this);
	cfgHandler->connectListView(rif.cfgList);

	DummyDelegate *delegate = new DummyDelegate;
	rif.cfgList->setItemDelegate( delegate );

	// Load previous session
	rif.terminalBox->setChecked( QtWine::settings->value("reginstaller/terminal_checkbox_enabled", FALSE).toBool() );
	rif.logBox->setChecked( QtWine::settings->value("reginstaller/log_checkbox_enabled", FALSE).toBool() );
	rif.logEdit->setText( QtWine::settings->value("reginstaller/log_lineEdit_text").toString() );
}

regInstaller::~regInstaller()
{
	cfgHandler->disconnectListView(rif.cfgList);
}

void regInstaller::on_OKButton_clicked()
{
	if ( filename.isEmpty() )
	{	qDebug("In function regInstaller::on_OKButton_clicked(): error: filename is empty."); exit(1);	}

	// READ OPTIONS
	QString logFile;
	if ( rif.logBox->isChecked() )
		logFile = rif.logEdit->text();

	QString workdir = QFileInfo(filename).absolutePath();

	// START WINE
	if ( rif.terminalBox->isChecked() )
	{
		saveSession();
		WineLauncher::startTerminal( cfgHandler->getCurrentCfgName(rif.cfgList), "regedit", QStringList() << filename, logFile );
		exit(0);
	}
	else
	{
		WineLauncher *regedit = new WineLauncher;
		regedit->setWorkDir( workdir );
		regedit->setSilent( TRUE );
		regedit->setLogFile( logFile );
		regedit->setCfgName(cfgHandler->getCurrentCfgName(rif.cfgList));
		regedit->setQuitMode( WineLauncher::quit );
		regedit->startWine( "regedit", QStringList() << filename );
		saveSession();
	}

}

void regInstaller::on_HelpButton_clicked()
{
	QtWineInformation::about();
}

void regInstaller::setFileName(QString name)
{
	filename = name;
	QFile regfile;
	regfile.setFileName( filename );
	if ( regfile.open(QIODevice::ReadOnly | QIODevice::Text) )
	{
		QTextStream ts(&regfile);
		rif.textBrowser->append( ts.readAll() );
		regfile.close();
	}
	rif.textBrowser->verticalScrollBar()->setValue( rif.textBrowser->verticalScrollBar()->minimum() ); // scroll to top
}

void regInstaller::setLog(QString filename)
{
	if ( !filename.isEmpty() )
	{
		if (!rif.logBox->isChecked())
			rif.logBox->setChecked(TRUE);
		rif.logEdit->setText(filename);
	}
}

void regInstaller::saveSession()
{
	QtWine::settings->setValue( "reginstaller/terminal_checkbox_enabled", rif.terminalBox->isChecked() );
	QtWine::settings->setValue( "reginstaller/log_checkbox_enabled", rif.logBox->isChecked() );
	QtWine::settings->setValue( "reginstaller/log_lineEdit_text", rif.logEdit->text() );
}

void regInstaller::on_browseButton_clicked()
{
	rif.logEdit->setText( QFileDialog::getSaveFileName( this, "Choose a log file", "/home" , "Any files (*)" ) );
}
